@@ -108,11 +108,17 @@ static void AGUIX_im_dest_callback( XIM callim, XPointer client_data, XPointer c
 long AGUIX::timerEvent = 0;
 std::map<std::string,int> AGUIX::_colors_for_widgets;
 
+static void (*other_sighandler)( int ) = NULL;
+
 #ifdef USE_AGUIXTIMER
 static void aguix_timer( int s )
 {
   if ( s == SIGALRM ) {
     AGUIX::timerEvent++;
+
+    if ( other_sighandler != NULL ) {
+        other_sighandler( s );
+    }
   }
 }
 #endif
@@ -122,7 +128,7 @@ AGUIX::AGUIX( int argc, char **argv, const std::string &classname ) : m_argc( ar
                                                                       m_classname( classname )
 {
 #ifdef USE_AGUIXTIMER
-  struct sigaction sig_ac;
+    struct sigaction sig_ac, old_sig_ac;
 #endif
 
   initOK=False;
@@ -152,7 +158,15 @@ AGUIX::AGUIX( int argc, char **argv, const std::string &classname ) : m_argc( ar
 #ifdef USE_AGUIXTIMER
   memset( &sig_ac, 0, sizeof( sig_ac ) );
   sig_ac.sa_handler = aguix_timer;
-  sigaction( SIGALRM, &sig_ac, NULL );
+  sigemptyset( &sig_ac.sa_mask );
+
+  sigaction( SIGALRM, &sig_ac, &old_sig_ac );
+
+  if ( old_sig_ac.sa_handler != SIG_ERR &&
+       old_sig_ac.sa_handler != SIG_DFL &&
+       old_sig_ac.sa_handler != SIG_IGN ) {
+      other_sighandler = old_sig_ac.sa_handler;
+  }
 #endif
 
   m_open_popup_counter = 0;
@@ -262,6 +276,8 @@ AGUIX::~AGUIX()
 {
   AGMessage *agmsg;
 
+  destroyBGHandlers();
+
   disableTimer();
   while((agmsg=getAGMsg())!=NULL) ReplyMessage(agmsg);
   if(checkX()==True) {
@@ -282,6 +298,8 @@ void AGUIX::panic(const char *msg)
 
 void AGUIX::closeX()
 {
+    destroyBGHandlers();
+
   destroyGroupWin();
 
   while ( fonts.empty() == false ) {
@@ -2757,3 +2775,56 @@ AWindow *AGUIX::getFocusedAWindow()
 
     return findAWindow( m_current_xfocus_window );
 }
+
+void AGUIX::registerBGHandler( AWindow *window, const RefCount< BackgroundMessageHandler > &handler )
+{
+    if ( ! window ) return;
+
+    if ( m_bg_handlers.count( window ) > 0 ) {
+        m_bg_handler_cleanup_list.push_back( m_bg_handlers[ window ] );
+    }
+    m_bg_handlers[ window ] = handler;
+}
+
+void AGUIX::unregisterBGHandler( AWindow *window )
+{
+    if ( ! window ) return;
+
+    /* since the handler may remove it during its execution we still need a valid
+     *  handle so we first move it to a cleanup list which gets clear after execution
+     */
+    if ( m_bg_handlers.count( window ) > 0 ) {
+        m_bg_handler_cleanup_list.push_back( m_bg_handlers[ window ] );
+        m_bg_handler_erase_handler.push_back( window );
+    }
+}
+
+void AGUIX::executeBGHandlers( AGMessage &msg )
+{
+    std::map< AWindow *, RefCount< BackgroundMessageHandler > >::iterator it1;
+
+    /* TODO check whether window still exists */
+    for ( it1 = m_bg_handlers.begin();
+          it1 != m_bg_handlers.end();
+          it1++ ) {
+        it1->second->handleAGUIXMessage( msg );
+    }
+    m_bg_handler_cleanup_list.clear();
+
+    for ( std::list< AWindow *>::iterator it2 = m_bg_handler_erase_handler.begin();
+	  it2 != m_bg_handler_erase_handler.end();
+	  it2++ ) {
+        m_bg_handlers.erase( *it2 );
+    }
+    m_bg_handler_erase_handler.clear();
+}
+
+/*
+ * method to clean up BG handler
+ * their destructor will be called so they hopefully release their resources
+ */
+void AGUIX::destroyBGHandlers()
+{
+    m_bg_handlers.clear();
+    m_bg_handler_cleanup_list.clear();
+}
