@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2009 Ralf Hoffmann.
+ * Copyright (C) 2001-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -26,6 +26,7 @@
 #include "lowlevelfunc.h"
 #include "message.h"
 #include "util.h"
+#include "refcount.hh"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -45,6 +46,7 @@
 
 #include "aguixfont.hh"
 #include "aguixcolor.hh"
+#include "backgroundmessagehandler.hh"
 
 class AWindow;
 class PopUpWindow;
@@ -229,6 +231,11 @@ public:
   int addDefaultColors();
 
     AWindow *getFocusedAWindow();
+
+    void registerBGHandler( AWindow *window, const RefCount< BackgroundMessageHandler > &handler );
+    void unregisterBGHandler( AWindow *window );
+    void executeBGHandlers( AGMessage &msg );
+    void destroyBGHandlers();
 private:
   Display *dsp;
   int scr;
@@ -330,6 +337,13 @@ private:
   int m_open_popup_counter;
 
   Window m_current_xfocus_window;
+
+    /* background handler for some window */
+    std::map< AWindow *, RefCount< BackgroundMessageHandler > > m_bg_handlers;
+
+    /* temporary list for unregister to cleanup handler after execution */
+    std::list< RefCount< BackgroundMessageHandler > > m_bg_handler_cleanup_list;
+    std::list< AWindow *> m_bg_handler_erase_handler;
 };
 
 #endif
