@@ -369,9 +369,6 @@ bool Button::handleMessage(XEvent *E,Message *msg)
 	   ( msg->button == Button1 ) ||
 	   ( ( msg->button == Button4 ) && ( allowWheel == true ) ) ||
 	   ( ( msg->button == Button5 ) && ( allowWheel == true ) ) ) {
-	int mx,my;
-	mx=msg->mousex;
-	my=msg->mousey;
 	if(msg->type==ButtonPress) {
 	  takeFocus();
 	  if(msg->window==win) {
