@@ -254,12 +254,8 @@ bool CycleButton::handleMessage(XEvent *E,Message *msg)
   AGMessage *agmsg;
   if((msg->type==ButtonPress)||(msg->type==ButtonRelease)) {
     if ( msg->window == win ) {
-      int mx,my;
-
       takeFocus();
 
-      mx=msg->mousex;
-      my=msg->mousey;
       if(msg->type==ButtonPress) {
 	if(msg->window==win) {
 	  setState(1);
