@@ -282,13 +282,11 @@ void FieldListView::setFieldWidth( int field, int width )
  */
 void FieldListView::setText( int row, int field, std::string text, bool update_simple_set )
 {
-  Content *te;
   int tl;
 
   if ( ( row < 0 ) || ( row >= elements ) ) return;
   if ( field < 0 ) return;
 
-  te = elementarray[ row ];
   // make changes to te
   
   // test if field already exists
@@ -1790,7 +1788,7 @@ void FieldListView::handleHBar( Message *msg )
   if ( isCreated() == false ) return;
   int mx, my;
   int dir;
-  int hx, hy, hw, hh;
+  int hx, hw, hh;
   int maxtextwidth = getMaxTextWidth();
   int tx, ty, tw, th;
   double b = 0;
@@ -1800,7 +1798,6 @@ void FieldListView::handleHBar( Message *msg )
 
   hw = getInnerWidth();
   hh = hbar_height;
-  hy = 0;
   hx = 0;
 
   // consider empty area after last field 
@@ -1963,7 +1960,7 @@ void FieldListView::handleVBar(Message *msg)
   if ( isCreated() == false ) return;
   int mx, my;
   int dir;
-  int vx, vy, vw, vh;
+  int vy, vw, vh;
   int tx, ty, tw, th;
   double b = 1;
   int curelements = getElements();
@@ -1973,7 +1970,6 @@ void FieldListView::handleVBar(Message *msg)
 
   vh = getInnerHeight();
   vw = vbar_width;
-  vx = 0;
   vy = 0;
 
   th = vh;
@@ -2953,7 +2949,10 @@ void FieldListView::redrawHeader()
   //TODO: ausloesen innerhalb von Content?
   std::string s;
   int sx, ex, f, fakefield;
-  int hh, vsx, vex;
+  int hh;
+#if 0
+  int vsx, vex;
+#endif
   align_t usedAlign;
   int tw, tx;
   XRectangle clip_rect;
@@ -3003,10 +3002,10 @@ void FieldListView::redrawHeader()
       // only draw header for non-empty fields
       if ( ( sx < ( xoffset + getInnerWidth() ) ) && ( ex > xoffset ) ) {
 	// field visible
+#if 0
 	vsx = a_max( sx, xoffset );
 	vex = a_min( xoffset + getInnerWidth(), ex );
 
-#if 0
 	_aguix->setFG( ( fieldtextclicked == f ) ? 1 : 2 );
 	_aguix->DrawLine( use_pixmap,
 			  use_ox + vsx - xoffset,
