@@ -1,6 +1,6 @@
 /* fieldlistview.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2009 Ralf Hoffmann.
+ * Copyright (C) 2002-2010 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -44,6 +44,7 @@ public:
   FieldListView &operator=( const FieldListView &other );
 
   void setNrOfFields( int nv );
+  int getNrOfFields() const;
   void setText( int row, int field, std::string text, bool update_simple_set = false );
   std::string getText( int row, int field ) const;
   void trimElements();
@@ -115,7 +116,7 @@ public:
   void setSelectHandler( void (*nsh)( FieldListView*, int element ) );
   void showActive();
   void centerActive();
-  int setFont (char* );
+  int setFont ( const char * );
   virtual const char *getType() const;
   virtual bool isType( const char *type ) const;
   virtual bool isParent( Window ) const;
