@@ -111,21 +111,10 @@ void StringGadget::setData(int tdata)
 
 void StringGadget::redraw()
 {
-  int newbg;
-
   if ( isCreated() == true ) {
     prepareBG();
 
     _aguix->ClearWin(win);
-    if(active==true) {
-      if ( _aguix->getNumberOfColorsForType( AGUIXColor::USER_COLOR ) > 7 ) {
-	newbg=7;
-      } else {
-	newbg=0;
-      }
-    } else {
-      newbg=0;
-    }
     
     _aguix->setFG(2);
     _aguix->DrawLine(win,0,_h-1,0,0);
