@@ -26,6 +26,7 @@
 #include <stdarg.h>
 #include <functional>
 #include <stdlib.h>
+#include <cmath>
 
 int createLines(const char *text,char ***ret_lines)
 {
@@ -222,18 +223,21 @@ namespace AGUIXUtils
     std::string bytes_to_human_readable_f( loff_t number,
                                            int threshold,
                                            int precision,
-                                           byte_multiplier_t suffix_format )
+                                           byte_multiplier_t suffix_format,
+                                           loff_t precision_hint )
     {
         return bytes_to_human_readable_f( (double)number,
                                           threshold,
                                           precision,
-                                          suffix_format );
+                                          suffix_format,
+                                          (double)precision_hint );
     }
 
     std::string bytes_to_human_readable_f( double number,
                                            int threshold,
                                            int precision,
-                                           byte_multiplier_t suffix_format )
+                                           byte_multiplier_t suffix_format,
+                                           double precision_hint )
     {
         std::string return_str;
         struct {
@@ -284,6 +288,20 @@ namespace AGUIXUtils
         }
 
         double f = number / suffix_list[current_level].mod;
+        double new_precision_hint = precision_hint / suffix_list[current_level].mod;
+
+        if ( new_precision_hint > 0 ) {
+            double variable_precision = log( new_precision_hint ) / log( 10 );
+
+            if ( variable_precision >= 0 ) {
+                precision = 0;
+            } else {
+                variable_precision = ceil( - variable_precision );
+                if ( variable_precision < (double)precision ) {
+                    precision = (int)variable_precision;
+                }
+            }
+        }
 
         char formatStr[ sizeof( "%.xxf %s" ) + 1 ];
 
@@ -294,4 +312,23 @@ namespace AGUIXUtils
 
         return return_str;
     }
+
+    int calc_precision( double v )
+    {
+        int precision = 0;
+        
+        if ( v > 0 ) {
+            double variable_precision = log( v ) / log( 10 );
+            
+            if ( variable_precision >= 0 ) {
+                precision = 0;
+            } else {
+                variable_precision = ceil( - variable_precision );
+                precision = (int)variable_precision;
+            }
+        }
+        
+        return precision;
+    }
+
 }
