@@ -24,6 +24,8 @@
 
 #include "aguixdefs.h"
 #include <string>
+#include <sstream>
+#include <stdexcept>
 
 int createLines(const char*,char ***);
 
@@ -50,11 +52,49 @@ namespace AGUIXUtils
     std::string bytes_to_human_readable_f( loff_t number,
                                            int threshold = 1,
                                            int precision = 1,
-                                           byte_multiplier_t suffix_format = BM_IEC );
+                                           byte_multiplier_t suffix_format = BM_IEC,
+                                           loff_t precision_hint = 0 );
     std::string bytes_to_human_readable_f( double number,
                                            int threshold = 1,
                                            int precision = 1,
-                                           byte_multiplier_t suffix_format = BM_IEC );
+                                           byte_multiplier_t suffix_format = BM_IEC,
+                                           double precision_hint = 0.0 );
+
+    template< class T > std::string convertToString( const T &v )
+    {
+	std::ostringstream osstr1;
+
+	osstr1 << v;
+	
+	return osstr1.str();
+    }
+
+    template< class T > T convertFromString( const std::string &s,
+					     std::ios_base &(*stream_manip_func)( std::ios_base & ) = std::dec )
+    {
+	std::istringstream isstr1( s );
+
+	T v;
+
+	isstr1 >> stream_manip_func;
+	isstr1 >> v;
+
+	if ( isstr1.fail() ) throw std::runtime_error( "convertFromString failed" );
+
+	return v;
+    }
+
+    template< class T > bool convertFromString( const std::string &s, T &v )
+    {
+	try {
+	    v = convertFromString<T>( s );
+	} catch ( const std::runtime_error &e ) {
+	    return false;
+	}
+	return true;
+    }
+
+    int calc_precision( double v );
 }
 
 #endif
