@@ -1,6 +1,6 @@
 /* condparser.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004-2006 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2004-2006,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,9 +21,15 @@
 
 #include "condparser.h"
 #include <aguix/lowlevelfunc.h>
+#include <aguix/awindow.h>
+#include <aguix/acontainer.h>
+#include <aguix/fieldlistview.h>
+#include <aguix/button.h>
 #include "execlass.h"
 #include "fileentry.hh"
 #include "worker.h"
+#include "datei.h"
+#include "worker_locale.h"
 
 struct CondParser::deftokens CondParser::keywords[] = {
   { "lasterror", CondParser::TOK_LASTERROR },
