@@ -385,7 +385,8 @@ struct mytoken tokenlist[]={
   { SWITCHTONEXTBANK_WCP, "switchtonextbank" },
   { SWITCHTOPREVBANK_WCP, "switchtoprevbank" },
   { SWITCHTOBANKNR_WCP, "switchtobanknr" },
-  { BANKNR_WCP, "banknr" }
+  { BANKNR_WCP, "banknr" },
+  { USE_VIRTUAL_TEMP_COPIES_WCP, "usevirtualtempcopies" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
