@@ -1,6 +1,6 @@
 /* copyopwin.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2006 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2006,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,6 +21,16 @@
 
 #include "worker.h"
 #include "copyopwin.hh"
+#include <aguix/util.h>
+#include <aguix/lowlevelfunc.h>
+#include <aguix/awindow.h>
+#include <aguix/button.h>
+#include <aguix/bevelbox.h>
+#include <aguix/solidbutton.h>
+#include "worker_locale.h"
+#include "datei.h"
+
+#define HUMAN_READABLE_DIALOG 1
 
 CopyOpWin::CopyOpWin( AGUIX*taguix, bool _move )
 {
@@ -349,15 +359,33 @@ CopyOpWin::redraw()
       lastbytes = copied_bytes_curfile;
       lasttime = curtime;
     }
-    
-    MakeLong2NiceStr( copied_bytes_curfile, copied_bytes_curfile_str );
 
-    MakeLong2NiceStr( bytes_curfile, bytes_curfile_str );
-    snprintf( tstr, sizeof( tstr ), "%s / %s @ %.2f KB/s",
-	      copied_bytes_curfile_str.c_str(),
-	      bytes_curfile_str.c_str(),
-	      lastrate / 1024.0 );
-    tstr[ sizeof( tstr ) - 1 ] = '\0';
+    if ( HUMAN_READABLE_DIALOG ) {
+        copied_bytes_curfile_str = AGUIXUtils::bytes_to_human_readable_f( (double)copied_bytes_curfile,
+                                                                          1, ( lastrate > 0.0 ) ? 5 : 0,
+                                                                          AGUIXUtils::BM_SYSTEM_SETTING,
+                                                                          lastrate );
+        bytes_curfile_str = AGUIXUtils::bytes_to_human_readable_f( (double)bytes_curfile,
+                                                                   1, ( lastrate > 0.0 ) ? 5 : 0,
+                                                                   AGUIXUtils::BM_SYSTEM_SETTING,
+                                                                   lastrate );
+
+        snprintf( tstr, sizeof( tstr ), "%s / %s @ %s/s",
+                  copied_bytes_curfile_str.c_str(),
+                  bytes_curfile_str.c_str(),
+                  AGUIXUtils::bytes_to_human_readable_f( lastrate ).c_str() );
+        tstr[ sizeof( tstr ) - 1 ] = '\0';
+    } else {
+        MakeLong2NiceStr( copied_bytes_curfile, copied_bytes_curfile_str );
+
+        MakeLong2NiceStr( bytes_curfile, bytes_curfile_str );
+        snprintf( tstr, sizeof( tstr ), "%s / %s @ %.2f KB/s",
+                  copied_bytes_curfile_str.c_str(),
+                  bytes_curfile_str.c_str(),
+                  lastrate / 1024.0 );
+        tstr[ sizeof( tstr ) - 1 ] = '\0';
+    }
+
     filetext->setText(tstr);
     tw = filetext->getX() + filetext->getWidth() + window->getBorderWidth();
     if ( tw > melw ) {
@@ -368,17 +396,30 @@ CopyOpWin::redraw()
     if(difftime2>0) {
       rate = (double)copied_bytes_curfile * 1000000.0 / difftime2;
     } else rate=0.0;
-    snprintf( tstr, sizeof( tstr ), "%.2f KB/s", rate / 1024.0 );
+
+    if ( HUMAN_READABLE_DIALOG ) {
+        snprintf( tstr, sizeof( tstr ), "%s/s", AGUIXUtils::bytes_to_human_readable_f( rate ).c_str() );
+    } else {
+        snprintf( tstr, sizeof( tstr ), "%.2f KB/s", rate / 1024.0 );
+    }
+
     tstr[ sizeof( tstr ) - 1 ] = '\0';
     fileavgtext->setText( tstr );
 
+    int rate_precision = AGUIXUtils::calc_precision( rate * 100.0 / (double)bytes_curfile );
+    if ( rate_precision < 0 ) rate_precision = 0;
+
     if(bytes_curfile>0)
       rate = (double)copied_bytes_curfile/(double)bytes_curfile;
     else
       rate=0.0;
     if ( rate < 0.01 )
       rate = 0.0;
-    snprintf( tstr, sizeof( tstr ), "%.2f %%", rate * 100.0 );
+
+    std::string fraction_str = AGUIXUtils::formatStringToString( "%%.%df %%%%",
+                                                                 rate_precision );
+
+    snprintf( tstr, sizeof( tstr ), fraction_str.c_str(), rate * 100.0 );
     tstr[ sizeof( tstr ) - 1 ] = '\0';
     fsb->setText(tstr);
     fsb->resize( w_max( (int)( sbw * rate ), 2 ), fsb->getHeight() );
@@ -391,14 +432,34 @@ CopyOpWin::redraw()
       rate = (double)copied_bytes * 1000000.0 / difftime2;
     } else rate=0.0;
 
-    MakeLong2NiceStr( copied_bytes, copied_bytes_str );
-    if(slim==true) {
-      snprintf( tstr, sizeof( tstr ), "%s @ %.2f KB/s", copied_bytes_str.c_str(), rate / 1024.0 );
-      tstr[ sizeof( tstr ) - 1 ] = '\0';
+    if ( HUMAN_READABLE_DIALOG ) {
+        copied_bytes_str = AGUIXUtils::bytes_to_human_readable_f( (double)copied_bytes,
+                                                                  1, ( rate > 0.0 ) ? 5 : 0,
+                                                                  AGUIXUtils::BM_SYSTEM_SETTING,
+                                                                  rate );
+
+        if(slim==true) {
+            snprintf( tstr, sizeof( tstr ), "%s @ %s/s", copied_bytes_str.c_str(), AGUIXUtils::bytes_to_human_readable_f( rate ).c_str() );
+            tstr[ sizeof( tstr ) - 1 ] = '\0';
+        } else {
+            bytes_str = AGUIXUtils::bytes_to_human_readable_f( (double)bytes,
+                                                               1, ( rate > 0.0 ) ? 5 : 0,
+                                                               AGUIXUtils::BM_SYSTEM_SETTING,
+                                                               rate );
+
+            snprintf( tstr, sizeof( tstr ), "%s / %s @ %s/s", copied_bytes_str.c_str(), bytes_str.c_str(), AGUIXUtils::bytes_to_human_readable_f( rate ).c_str() );
+            tstr[ sizeof( tstr ) - 1 ] = '\0';
+        }
     } else {
-      MakeLong2NiceStr( bytes, bytes_str );
-      snprintf( tstr, sizeof( tstr ), "%s / %s @ %.2f KB/s", copied_bytes_str.c_str(), bytes_str.c_str(), rate / 1024.0 );
-      tstr[ sizeof( tstr ) - 1 ] = '\0';
+        MakeLong2NiceStr( copied_bytes, copied_bytes_str );
+        if(slim==true) {
+            snprintf( tstr, sizeof( tstr ), "%s @ %.2f KB/s", copied_bytes_str.c_str(), rate / 1024.0 );
+            tstr[ sizeof( tstr ) - 1 ] = '\0';
+        } else {
+            MakeLong2NiceStr( bytes, bytes_str );
+            snprintf( tstr, sizeof( tstr ), "%s / %s @ %.2f KB/s", copied_bytes_str.c_str(), bytes_str.c_str(), rate / 1024.0 );
+            tstr[ sizeof( tstr ) - 1 ] = '\0';
+        }
     }
     
     globtext->setText(tstr);
@@ -409,13 +470,21 @@ CopyOpWin::redraw()
     }
     
     if(slim==false) {
+        int rate_precision = AGUIXUtils::calc_precision( rate * 100.0 / (double)bytes );
+        if ( rate_precision < 0 ) rate_precision = 0;
+
       if(bytes>0)
         rate = (double)copied_bytes/(double)bytes;
       else
         rate=0.0;
       if ( rate < 0.01 )
         rate = 0.0;
-      snprintf( tstr, sizeof( tstr ), "%.2f %%", rate * 100.0 );
+
+      std::string fraction_str = AGUIXUtils::formatStringToString( "%%.%df %%%%",
+                                                                   rate_precision );
+
+      snprintf( tstr, sizeof( tstr ), fraction_str.c_str(), rate * 100.0 );
+
       tstr[ sizeof( tstr ) - 1 ] = '\0';
       gsb->setText(tstr);
       gsb->resize( w_max( (int)( sbw * rate ), 2 ), gsb->getHeight() );
