@@ -27,6 +27,20 @@
 
 class AWidth;
 
+class CopyfileProgressCallback
+{
+public:
+    virtual ~CopyfileProgressCallback() = 0;
+
+    typedef enum {
+        COPYFILE_CONTINUE,
+        COPYFILE_ABORT
+    } callback_return_t;
+
+    virtual callback_return_t progress_callback( loff_t current_bytes,
+                                                 loff_t total_bytes ) = 0;
+};
+
 class Datei
 {
 public:
@@ -72,7 +86,8 @@ public:
   static char *shrinkFilename( const char *str, int maxlength, AWidth &lencalc );
   static loff_t fileSize( const char * );
   static char *getRelativePath( const char *source, const char *destdir );
-  static int copyfile( const char *dest, const char *source );
+    static int copyfile( const char *dest, const char *source,
+                         CopyfileProgressCallback *progress_callback = NULL );
 
   void configPutPair( const char *id, const char *info );
   void configPutPairNum( const char *id, int num );
