@@ -1,6 +1,6 @@
 /* dirbookmarkop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007-2008 Ralf Hoffmann.
+ * Copyright (C) 2007-2008,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,6 +31,9 @@
 #include "nwc_path.hh"
 #include "bookmarkdbproxy.hh"
 #include "nmspecialsourceext.hh"
+#include "worker.h"
+#include "worker_locale.h"
+#include "fileentry.hh"
 
 const char *DirBookmarkOp::name = "DirBookmarkOp";
 
