@@ -1,6 +1,6 @@
 /* fileentry.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2008,2010 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2008,2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,6 +21,7 @@
 
 #include "fileentry.hh"
 #include <aguix/lowlevelfunc.h>
+#include <aguix/fieldlistviewdnd.h>
 #include "wconfig.h"
 #include "grouphash.h"
 #include "pdatei.h"
@@ -589,7 +590,7 @@ bool FileEntry::isExe( bool fastTest ) const
   return false;
 }
 
-bool FileEntry::match(char* pattern)
+bool FileEntry::match( const char* pattern )
 {
   if(fnmatch(pattern,name,0)==0) return true;
   return false;
