@@ -52,7 +52,9 @@ HWVolumeManager::HWVolumeManager( const std::string &fstab_location,
     m_mtab_table( mtab_location ),
     m_mount_command( HW_VM_MOUNT_CMD ),
     m_unmount_command( HW_VM_UNMOUNT_CMD ),
-    m_partition_file( HW_VM_PARTS )
+    m_partition_file( HW_VM_PARTS ),
+    m_eject_command( HW_VM_EJECT_CMD ),
+    m_closetray_command( HW_VM_CLOSETRAY_CMD )
 {
     HALconnectionInit();
 }
@@ -208,6 +210,24 @@ int HWVolumeManager::umount( HWVolume &vol, std::string &error_return )
     }
 }
 
+int HWVolumeManager::eject( HWVolume &vol, std::string &error_return )
+{
+    if ( ! vol.getUDI().empty() ) {
+        return halEject( vol, error_return );
+    } else {
+        return cmdEject( vol, error_return );
+    }
+}
+
+int HWVolumeManager::closeTray( HWVolume &vol, std::string &error_return )
+{
+    if ( ! vol.getUDI().empty() ) {
+        return halCloseTray( vol, error_return );
+    } else {
+        return cmdCloseTray( vol, error_return );
+    }
+}
+
 void HWVolumeManager::update( HWVolume &vol )
 {
     if ( ! vol.getUDI().empty() ) {
@@ -557,6 +577,24 @@ void HWVolumeManager::setUnmountCommand( const std::string &cmd )
     }
 }
 
+void HWVolumeManager::setEjectCommand( const std::string &cmd )
+{
+    if ( ! cmd.empty() ) {
+        m_eject_command = cmd;
+    } else {
+        m_eject_command = HW_VM_EJECT_CMD;
+    }
+}
+
+void HWVolumeManager::setCloseTrayCommand( const std::string &cmd )
+{
+    if ( ! cmd.empty() ) {
+        m_closetray_command = cmd;
+    } else {
+        m_closetray_command = HW_VM_CLOSETRAY_CMD;
+    }
+}
+
 int HWVolumeManager::halMount( HWVolume &vol, std::string &error_return )
 {
     if ( vol.isMounted() == true ) {
@@ -887,6 +925,270 @@ int HWVolumeManager::cmdUnmount( HWVolume &vol, std::string &error_return )
     return 0;
 }
 
+int HWVolumeManager::halEject( HWVolume &vol, std::string &error_return )
+{
+    if ( vol.getUDI().empty() ) {
+        error_return = catalog.getLocale( 923 );
+        return 1;
+    }
+
+#ifdef HAVE_HAL_DBUS
+    DBusMessage *message = NULL;
+    DBusMessage *reply = NULL;
+    DBusError error;
+#endif
+    bool eject_failed = true;
+
+#ifdef HAVE_HAL_DBUS
+    if ( HALreconnect() == 0 ) {
+
+        dbus_error_init( &error );
+
+        // check whether there is a eject method
+        std::list< std::string > method_list;
+
+        try {
+            method_list = getStrlistProperty( vol.getUDI().c_str(), "org.freedesktop.Hal.Device.Storage.method_names" );
+        } catch ( int ) {
+        }
+
+        if ( std::find( method_list.begin(),
+                        method_list.end(),
+                        "Eject" ) != method_list.end() ) {
+
+            try {
+                message = dbus_message_new_method_call( "org.freedesktop.Hal", 
+                                                        vol.getUDI().c_str(),
+                                                        "org.freedesktop.Hal.Device.Storage",
+                                                        "Eject" );
+                if ( ! message ) {
+                    //TODO translate
+                    error_return = "Eject failed: Unable to create DBus message";
+                    throw 1;
+                }
+
+                const char *options[] = { NULL };
+                int num_options = 0;
+                const char **options_p = options;
+            
+                if ( ! dbus_message_append_args( message, 
+                                                 DBUS_TYPE_ARRAY, DBUS_TYPE_STRING, &options_p, num_options,
+                                                 DBUS_TYPE_INVALID ) ) {
+                    //TODO translate?
+                    error_return = "Eject failed: Unable to add arguments to DBus message";
+                    throw 2;
+                }
+            
+                reply = dbus_connection_send_with_reply_and_block( m_dbus_conn,
+                                                                   message,
+                                                                   -1,
+                                                                   &error );
+                if ( ! reply ) {
+                    throw 3;
+                }
+
+                if ( dbus_error_is_set( &error ) ) {
+                    throw 4;
+                }
+            
+#if 0
+                int hal_retcode;
+
+                // I do not do this test anymore, on some systems its INT32
+                // on other UINT32
+                // beside, other tools (gnome-mount) do not check it either
+                if ( ! dbus_message_get_args( reply, 
+                                              &error,
+                                              DBUS_TYPE_UINT32, &hal_retcode,
+                                              DBUS_TYPE_INVALID ) ) {
+                    throw 4;
+                }
+            
+                if ( hal_retcode != 0 ) {
+                    throw 5;
+                }
+#endif
+                eject_failed = false;
+            } catch ( int e ) {
+                if ( dbus_error_is_set( &error ) ) {
+                    error_return = AGUIXUtils::formatStringToString( catalog.getLocale( 925 ),
+                                                                     error.name,
+                                                                     error.message );
+                    dbus_error_free( &error );
+                }
+            }
+
+            if ( message ) dbus_message_unref( message );
+            if ( reply ) dbus_message_unref( reply );
+        } else {
+            // no eject method
+            //TODO translate?
+            error_return = "Eject failed: No Eject method";
+        }
+    }
+#endif
+    if ( eject_failed ) return 1;
+
+    return 0;
+}
+
+int HWVolumeManager::cmdEject( HWVolume &vol, std::string &error_return )
+{
+    FlagReplacer::FlagProducerMap fl;
+
+    fl.registerFlag( "f", vol.getDevice() );
+    fl.registerFlag( "d", vol.getDevice() );
+
+    FlagReplacer rpl( fl );
+  
+    std::string exestr = rpl.replaceFlags( m_eject_command );
+
+    ExeClass ec( ExeClass::EXECUTE_NORMAL );
+
+    ec.addCommand( "%s", exestr.c_str() );
+    int ret = ec.getReturnCode();
+    if ( ret != 0 ) {
+        std::string error;
+        //TODO do not use a hard-coded limit
+        ec.readErrorOutput( error, 1024 );
+
+        error_return = error.substr( 0, error.find( '\n' ) );
+        return 1;
+    }
+    return 0;
+}
+
+int HWVolumeManager::halCloseTray( HWVolume &vol, std::string &error_return )
+{
+    if ( vol.getUDI().empty() ) {
+        error_return = catalog.getLocale( 924 );
+        return 1;
+    }
+
+#ifdef HAVE_HAL_DBUS
+    DBusMessage *message = NULL;
+    DBusMessage *reply = NULL;
+    DBusError error;
+#endif
+    bool closetray_failed = true;
+    
+#ifdef HAVE_HAL_DBUS
+    if ( HALreconnect() == 0 ) {
+
+        dbus_error_init( &error );
+
+        // check whether there is a closetray method
+        std::list< std::string > method_list;
+
+        try {
+            method_list = getStrlistProperty( vol.getUDI().c_str(), "org.freedesktop.Hal.Device.Storage.method_names" );
+        } catch ( int ) {
+        }
+
+        if ( std::find( method_list.begin(),
+                        method_list.end(),
+                        "CloseTray" ) != method_list.end() ) {
+
+            try {
+                message = dbus_message_new_method_call( "org.freedesktop.Hal", 
+                                                        vol.getUDI().c_str(),
+                                                        "org.freedesktop.Hal.Device.Storage",
+                                                        "CloseTray" );
+                if ( ! message ) {
+                    //TODO translate?
+                    error_return = "CloseTray failed: Unable to create DBus message";
+                    throw 1;
+                }
+
+                const char *options[] = { NULL };
+                int num_options = 0;
+                const char **options_p = options;
+            
+                if ( ! dbus_message_append_args( message, 
+                                                 DBUS_TYPE_ARRAY, DBUS_TYPE_STRING, &options_p, num_options,
+                                                 DBUS_TYPE_INVALID ) ) {
+                    //TODO translate?
+                    error_return = "CloseTray failed: Unable to add arguments to DBus message";
+                    throw 2;
+                }
+            
+                reply = dbus_connection_send_with_reply_and_block( m_dbus_conn,
+                                                                   message,
+                                                                   -1,
+                                                                   &error );
+                if ( ! reply ) {
+                    throw 3;
+                }
+            
+                if ( dbus_error_is_set( &error ) ) {
+                    throw 4;
+                }
+
+#if 0
+                int hal_retcode;
+
+                // see comment in halMount
+                if ( ! dbus_message_get_args( reply, 
+                                              &error,
+                                              DBUS_TYPE_UINT32, &hal_retcode,
+                                              DBUS_TYPE_INVALID ) ) {
+                    throw 4;
+                }
+            
+                if ( hal_retcode != 0 ) {
+                    throw 5;
+                }
+#endif
+                closetray_failed = false;
+            } catch ( int e ) {
+                if ( dbus_error_is_set( &error ) ) {
+                    error_return = AGUIXUtils::formatStringToString( catalog.getLocale( 926 ),
+                                                                     error.name,
+                                                                     error.message );
+                    dbus_error_free( &error );
+                }
+            }
+
+            if ( message ) dbus_message_unref( message );
+            if ( reply ) dbus_message_unref( reply );
+        } else {
+            // no closetray method
+            //TODO translate?
+            error_return = "CloseTray failed: No CloseTray method";
+        }
+    }
+#endif
+    if ( closetray_failed ) return 1;
+
+    return 0;
+}
+
+int HWVolumeManager::cmdCloseTray( HWVolume &vol, std::string &error_return )
+{
+    FlagReplacer::FlagProducerMap fl;
+
+    fl.registerFlag( "f", vol.getDevice() );
+    fl.registerFlag( "d", vol.getDevice() );
+
+    FlagReplacer rpl( fl );
+  
+    std::string exestr = rpl.replaceFlags( m_closetray_command );
+
+    ExeClass ec( ExeClass::EXECUTE_NORMAL );
+
+    ec.addCommand( "%s", exestr.c_str() );
+    int ret = ec.getReturnCode();
+    if ( ret != 0 ) {
+        std::string error;
+        //TODO do not use a hard-coded limit
+        ec.readErrorOutput( error, 1024 );
+
+        error_return = error.substr( 0, error.find( '\n' ) );
+        return 1;
+    }
+    return 0;
+}
+
 void HWVolumeManager::setPartitionFile( const std::string &file )
 {
     if ( ! file.empty() ) {
@@ -1023,3 +1325,127 @@ int HWVolumeManager::HALreconnect()
     return 0;
 #endif
 }
+
+std::list<HWVolume> HWVolumeManager::getEjectableDevices()
+{
+    std::list<HWVolume> l;
+#ifdef HAVE_HAL_DBUS
+    DBusError error;
+    int i;
+    int num_devices;
+    char **devices;
+    const char *udi;
+#endif
+
+    m_fstab_table.update();
+    m_mtab_table.update();
+    m_avail_parts = getAvailablePartitions();
+    std::set< w_osdevice_t > managed;
+
+#ifndef HAVE_HAL_DBUS
+    std::list< MountTableEntry > fstab_entries = m_fstab_table.getEntries();
+    for ( std::list< MountTableEntry >::const_iterator it1 = fstab_entries.begin();
+          it1 != fstab_entries.end();
+          it1++ ) {
+        if ( isDevice( it1->getDevice() ) ) {
+            //TODO check for duplicate entries?
+            HWVolume v;
+            v.setDevice( it1->getDevice() );
+
+            update( v );
+
+            managed.insert( getOSDevice( v.getDevice() ) );
+            l.push_back( v );
+        }
+    }
+#endif
+
+#ifdef HAVE_HAL_DBUS
+    if ( HALreconnect() == 0 ) {
+
+        dbus_error_init( &error );
+        devices = libhal_find_device_by_capability( m_hal_ctx, "storage",
+                                                    &num_devices, &error );
+        if ( devices != NULL ) {
+            for (i = 0; i < num_devices; i++) {
+                udi = devices[i];
+
+		// check whether there is a closetray method
+		std::list< std::string > method_list;
+		
+		try {
+		    method_list = getStrlistProperty( udi, "org.freedesktop.Hal.Device.Storage.method_names" );
+		} catch ( int ) {
+		}
+
+		if ( std::find( method_list.begin(),
+				method_list.end(),
+				"Eject" ) != method_list.end() ) {
+
+		    HWVolume v( udi );
+		    
+		    update( v );
+		    
+		    if ( managed.count( getOSDevice( v.getDevice() ) ) < 1 ) {
+			managed.insert( getOSDevice( v.getDevice() ) );
+			
+			l.push_back( v );
+		    }
+		}
+            }
+            libhal_free_string_array( devices );
+        } else {
+            if ( dbus_error_is_set( &error ) ) {
+                fprintf( stderr, "HAL Find Devices Error: %s\n", error.message );
+                dbus_error_free( &error );
+            }
+        }
+        dbus_error_init( &error );
+    }
+#endif
+
+    return l;
+}
+
+std::string HWVolumeManager::getDescription( const HWVolume &vol )
+{
+    if ( vol.getUDI().empty() ) {
+        return "";
+    }
+
+    std::string descr;
+
+#ifdef HAVE_HAL_DBUS
+    DBusError error;
+
+    if ( HALreconnect() == 0 ) {
+
+        dbus_error_init( &error );
+
+        std::string vendor, product;
+
+        try {
+            vendor = getStringProperty( vol.getUDI().c_str(), "info.vendor" );
+        } catch ( int ) {
+        }
+        try {
+            product = getStringProperty( vol.getUDI().c_str(), "info.product" );
+        } catch ( int ) {
+        }
+
+        if ( ! vendor.empty() ) {
+            descr = vendor;
+            descr += " ";
+        }
+        if ( ! product.empty() ) {
+            descr += product;
+        }
+
+        if ( dbus_error_is_set( &error ) ) {
+            fprintf( stderr, "HAL Error: %s\n", error.message );
+            dbus_error_free( &error );
+        }
+    }
+#endif
+    return descr;
+}
