@@ -1,6 +1,6 @@
 /* nmextlist.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008 Ralf Hoffmann.
+ * Copyright (C) 2001-2008,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,6 +22,12 @@
 #include "nmextlist.hh"
 #include "normalmode.h"
 #include "verzeichnis.hh"
+#include "simplelist.hh"
+#include "fileentry.hh"
+#include "nmexternfe.hh"
+#include "dnd.h"
+#include "nmspecialsourceext.hh"
+#include "datei.h"
 
 NMExtList::NMExtList()
 {
