@@ -42,7 +42,7 @@ void NormalMode::copy( struct NM_copyorder *copyorder )
     NM_CopyOp_Dir *cod1,*tcod;
     unsigned long files,dirs,gf,gd;
     loff_t bytes;
-    bool skip,cancel=false;
+    bool cancel=false;
     CopyOpWin *cowin;
     nm_copy_t ce1;
     bool nodatabase;
@@ -205,8 +205,6 @@ void NormalMode::copy( struct NM_copyorder *copyorder )
     copy_deletefe_list = new std::list<const FileEntry*>;
     copy_lvc_list = new std::list<NM_specialsourceInt*>;
 
-    skip=false;
-
     for ( iti1 = copylist->begin(); ( iti1 != copylist->end() ) && ( cancel == false ); iti1++ ) {
         ss1 = *iti1;
         if(nodatabase==false) {
@@ -719,7 +717,7 @@ NormalMode::nm_newname_t NormalMode::getNewName4File( const FileEntry *oldfe, st
     bool nameok=false,skip=false,cancel=false;
     char *return_str=NULL,*buttonstr,*textstr,*newdest;
     int erg;
-    Datei::d_fe_t se,lse;
+    Datei::d_fe_t lse;
     int round=1;
     nm_newname_t returnvalue=NM_NEWNAME_CANCEL;
     bool do_rename,trydel;
@@ -783,7 +781,6 @@ NormalMode::nm_newname_t NormalMode::getNewName4File( const FileEntry *oldfe, st
         strcpy(newdest,dest);
         if(strlen(dest)>1) strcat(newdest,"/");
         strcat(newdest,newname);
-        se=Datei::fileExistsExt(newdest);
         lse=Datei::lfileExistsExt(newdest);
 
         switch(lse) {
