@@ -90,14 +90,14 @@ VolumeManagerUI::VolumeManagerUI( AGUIX &aguix, HWVolumeManager &hwman ) : m_agu
     m_unmountb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0, catalog.getLocale( 886 ), 1, 0, 0 ),
                                                      0, 1, AContainer::CO_FIX ) );
     m_ejectb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0,
-                                                              catalog.getLocale( 920 ),
+                                                              catalog.getLocale( 965 ),
                                                               catalog.getLocale( 929 ),
                                                               1, 1,
                                                               0, 0,
                                                               0 ),
                                                   0, 2, AContainer::CO_FIX ) );
     m_closetrayb = dynamic_cast<Button*>( cont4->add( new Button( &m_aguix, 0, 0,
-                                                                  catalog.getLocale( 921 ),
+                                                                  catalog.getLocale( 966 ),
                                                                   catalog.getLocale( 930 ),
                                                                   1, 1,
                                                                   0, 0,
@@ -250,6 +250,10 @@ int VolumeManagerUI::mainLoop()
                       mountRow( m_lv->getActiveRow() );
                   } else if ( msg->key.key == XK_u ) {
                       unmountRow( m_lv->getActiveRow() );
+                  } else if ( msg->key.key == XK_o ) {
+                      ejectOrCloseTray( VOLMANUI_MENU_EJECT );
+                  } else if ( msg->key.key == XK_c ) {
+                      ejectOrCloseTray( VOLMANUI_MENU_CLOSETRAY );
                   }
                   break;
               case AG_FIELDLV_DOUBLECLICK:
