@@ -38,9 +38,7 @@ ListerPanel::~ListerPanel()
 
 int ListerPanel::create()
 {
-  int res;
-  
-  res = Panel::create();
+  Panel::create();
 
   char tstr[ A_BYTESFORNUMBER( int ) ];
   const int cmwmh = AContainer::ACONT_MINH +
