@@ -33,6 +33,8 @@
 #include <aguix/message.h>
 #include "hw_volume_manager.hh"
 #include <memory>
+#include "event_callbacks.hh"
+#include "temporaryfilecache.hh"
 
 class ListerMode;
 class Lister;
@@ -50,6 +52,7 @@ class WCHotkey;
 class WCButton;
 class WCPath;
 class PartSpace;
+class CopyfileProgressCallback;
 
 class Worker
 {
@@ -140,6 +143,10 @@ public:
 
     void shuffleButton( int dir );
     void switchToButtonBank( int nr );
+
+    EventCallbacks &getEventHandler();
+    TemporaryFileCache::TemporaryFileCacheEntry getTempCopy( const std::string &filename,
+                                                             CopyfileProgressCallback *progress_callback = NULL );
  protected:
   void createMainWin();
   void setupMainWin();
@@ -277,6 +284,7 @@ public:
     loff_t m_current_statebar_update_ms;
     void setStatebarUpdate( loff_t time_ms );
 
+    TemporaryFileCache m_temp_file_cache;
     ProcessHandler m_process_handler;
     void waitForEvent();
 
@@ -291,6 +299,10 @@ public:
     std::map< KeySym, int > m_ignored_keys;
 
     void updateSettingsFromWConfig();
+
+    EventCallbacks m_event_handler;
+    std::map< EventCallbacks::event_callback_type_t, bool > m_events_seen;
+    void fireSeenEvents();
 };
 
 #endif
