@@ -1,6 +1,6 @@
 /* worker_commands.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2009 Ralf Hoffmann.
+ * Copyright (C) 2001-2007,2009,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,6 +21,7 @@
 
 #include "worker.h"
 #include "worker_commands.h"
+#include "worker_locale.h"
 
 int Worker::getNrOfCommands()
 {
@@ -201,6 +202,9 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 58:
       fpr = new VolumeManagerOp();
       break;
+    case 59:
+      fpr = new SwitchButtonBankOp();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -269,6 +273,7 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( ModifyTabsOp::name ) == true ) type = 56;
   else if ( fpr->isName( ChangeLayoutOp::name ) == true ) type = 57;
   else if ( fpr->isName( VolumeManagerOp::name ) == true ) type = 58;
+  else if ( fpr->isName( SwitchButtonBankOp::name ) == true ) type = 59;
   return type;
 }
 
@@ -276,7 +281,7 @@ int Worker::getMaxModeNr()
 {
   // leider hardcoded, da aber die schlechte Methode in dieser Klasse bleibt, nicht so
   // schlimm
-  return 3;
+  return 4;
 }
 
 ListerMode *Worker::getMode4ID(int nr,Lister *parent)
@@ -289,6 +294,9 @@ ListerMode *Worker::getMode4ID(int nr,Lister *parent)
     case 2:
       lm=new InformationMode(parent);
       break;
+    case 3:
+      lm = new TextViewMode( parent );
+      break;
     default:
       lm=new NormalMode(parent);
       break;
@@ -305,6 +313,9 @@ const char *Worker::getNameOfMode( int nr )
     case 2:
       return InformationMode::getStaticType();
       break;
+    case 3:
+      return TextViewMode::getStaticType();
+      break;
   }
   return NormalMode::getStaticType();
 }
@@ -318,6 +329,9 @@ const char *Worker::getLocaleNameOfMode( int nr )
     case 2:
       return InformationMode::getStaticLocaleName();
       break;
+    case 3:
+      return TextViewMode::getStaticLocaleName();
+      break;
   }
   return NormalMode::getStaticLocaleName();
 }
@@ -327,6 +341,7 @@ int Worker::getID4Name( const char *str )
   if ( str == NULL ) return -1;
   if ( strcasecmp( str, ShowImageMode::getStaticType() ) == 0 ) return 1;
   if ( strcasecmp( str, InformationMode::getStaticType() ) == 0 ) return 2;
+  if ( strcasecmp( str, TextViewMode::getStaticType() ) == 0 ) return 3;
   if ( strcasecmp( str, NormalMode::getStaticType() ) == 0 ) return 0;
   return -1;
 }
@@ -337,6 +352,7 @@ int Worker::getID4Mode(ListerMode *lm)
   if(lm->isType("NormalMode")==true) type=0;
   else if(lm->isType("ShowImageMode")==true) type=1;
   else if(lm->isType("InformationMode")==true) type=2;
+  else if ( lm->isType( "TextViewMode" ) == true ) type = 3;
   return type;
 }
 
