@@ -1,6 +1,6 @@
 /* worker_commands.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2009 Ralf Hoffmann.
+ * Copyright (C) 2001-2009,2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -62,11 +62,13 @@
 #include "changelayoutop.hh"
 #include "enterdirop.hh"
 #include "volumemanagerop.hh"
+#include "switchbuttonbankop.hh"
 
 #include "listermode.h"
 #include "normalmode.h"
 #include "showimagemode.h"
 #include "informationmode.h"
+#include "textviewmode.hh"
 
 #endif
 
