@@ -27,7 +27,7 @@
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 962
+#define CATENTRY 970
 #define CATCOMENTRY 60
 #define CATFLAGENTRY 59
 
@@ -1064,6 +1064,14 @@ match any font." );
   catalog[959]=dupstring( "Switch to prev bank" );
   catalog[960]=dupstring( "Switch to bank number" );
   catalog[961]=dupstring( "Bank number:" );
+  catalog[962]=dupstring( "Search result is already shown by a different search window, creating a new one" );
+  catalog[963]=dupstring( "Locked" );
+  catalog[964]=dupstring( "Use temporary copies for all virtual files used for external programs" );
+  catalog[965]=dupstring( "Eject - o" );
+  catalog[966]=dupstring( "Close tray - c" );
+  catalog[967]=dupstring( "Go to entry but keep window" );
+  catalog[968]=dupstring( "Creating temporary file: %3.0f%% done..." );
+  catalog[969]=dupstring( "Creating temporary file: %3.0f%% done (total: %3.0f%%)..." );
 
 //  catalog[]=dupstring( "" );
   
