@@ -31,6 +31,9 @@
 #include <aguix/solidbutton.h>
 #include <aguix/button.h>
 #include "datei.h"
+#include <iostream>
+#include "nmexternfe.hh"
+#include "nwc_fsentry.hh"
 
 WPUStack::WPUStack()
 {
@@ -44,7 +47,7 @@ WPUStack::~WPUStack()
   delete [] stack;
 }
 
-void WPUStack::push( std::string elem )
+void WPUStack::push( const std::string &elem )
 {
   if ( elems >= s ) raise();
   stack[elems++] = elem;
@@ -108,16 +111,18 @@ struct wpucontext_deftokens {
 };
 
 //TODO vielleicht auch noch ONLYACTIVE untersttzen
-WPUContext::WPUContext( Worker *w, List *coms, ActionMessage *msg )
+WPUContext::WPUContext( Worker *w, List *coms, bool delete_commands_at_destroy, ActionMessage *msg )
 {
   int id;
   FunctionProto *fp;
   struct wpucontext_deftokens *p;
 
+  m_reference_count = 1;
   nr_of_stacks = 0;
   stacks = NULL;
   pc = 0;
   acoms = new ArrayList();
+  m_delete_commands_at_destroy = delete_commands_at_destroy;
   
   id = coms->initEnum();
   fp = (FunctionProto*)coms->getFirstElement( id );
@@ -131,6 +136,9 @@ WPUContext::WPUContext( Worker *w, List *coms, ActionMessage *msg )
   extlist[1] = NULL;
   worker = w;
 
+  m_progress_callback = new WPUProgressCallback( worker );
+  m_filesizes_calculated = false;
+
   curpos = 0;
   tokenval = -1;
   lastentry = 0;
@@ -200,6 +208,20 @@ WPUContext::WPUContext( Worker *w, List *coms, ActionMessage *msg )
 WPUContext::~WPUContext()
 {
   closeWin();
+
+  if ( m_delete_commands_at_destroy ) {
+      int id;
+      FunctionProto *fp1;
+
+      id = acoms->initEnum();
+      fp1 = (FunctionProto*)acoms->getFirstElement( id );
+      while ( fp1 != NULL ) {
+          delete fp1;
+          fp1 = (FunctionProto*)acoms->getNextElement( id );
+      }
+      acoms->closeEnum( id );
+  }
+
   delete acoms;
   for ( int i = 0; i < nr_of_stacks; i++ ) {
     delete stacks[i];
@@ -211,7 +233,6 @@ WPUContext::~WPUContext()
   if ( extlist[1] != NULL ) {
     delete extlist[1];
   }
-  freeTempNameList();
 }
 
 int WPUContext::continueAtLabel( const char *label )
@@ -1279,88 +1300,136 @@ bool WPUContext::getTakeDirs()
   return extorder.take_dirs;
 }
 
-const char *WPUContext::getTempName4File( const char *filename )
+void WPUContext::setUseVirtualTempCopies( bool nv )
 {
-  std::list<temp4filename_t*>::iterator it1;
-  worker_struct_stat stbuf;
-  temp4filename_t *el1;
-  char *newtempname;
-
-  if ( filename == NULL ) return NULL;
-
-  for ( it1 = tempnamelist.begin(); it1 != tempnamelist.end(); it1++ ) {
-    if ( *it1 != NULL ) {
-      if ( (*it1)->filename != NULL ) {
-	if ( strcmp( (*it1)->filename, filename ) == 0 ) {
-	  break;
-	}
-      }
-    }
-  }
-
-  if ( it1 != tempnamelist.end() ) {
-    return (*it1)->tempname;
-  }
-
-  if ( worker_lstat( filename, &stbuf ) != 0 ) return NULL;
-
-  if ( ! S_ISREG( stbuf.st_mode ) ) return NULL;
-
-  newtempname = Datei::createTMPName();
-
-  if ( newtempname == NULL ) return NULL;
-  
-  if ( Datei::copyfile( newtempname, filename ) != 0 ) {
-    if ( worker->getRequester() != NULL ) {
-      char *reqstr;
-      reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 618 ) ) + strlen( filename ) + 1 );
-      sprintf( reqstr, catalog.getLocale( 618 ), filename );
-      worker->getRequester()->request( catalog.getLocale( 347 ), reqstr, catalog.getLocale( 11 ) );
-      _freesafe( reqstr );
-    }
-    
-    worker_unlink( newtempname );
-    _freesafe( newtempname );
-    return NULL;
-  }
-  
-  el1 = new temp4filename_t();
-  el1->tempname = newtempname;
-  el1->filename = dupstring( filename );
-  if ( worker_lstat( newtempname, &stbuf ) != 0 ) el1->modtime = 0;
-  else el1->modtime = stbuf.st_mtime;
-  
-  tempnamelist.push_back( el1 );
-  return newtempname;
+  extorder.m_use_virtual_temp_copies = nv;
 }
 
-void WPUContext::freeTempNameList()
+bool WPUContext::getUseVirtualTempCopies() const
 {
-  std::list<temp4filename_t*>::iterator it1;
-  worker_struct_stat stbuf;
-  bool changed;
-
-  for ( it1 = tempnamelist.begin(); it1 != tempnamelist.end(); it1++ ) {
-    if ( *it1 != NULL ) {
-      changed = false;
-
-      if ( (*it1)->tempname != NULL ) {
-	if ( worker_lstat( (*it1)->tempname, &stbuf ) != 0 ) changed = true;
-	else if ( (*it1)->modtime != stbuf.st_mtime ) changed = true;
-	
-	if ( ( changed == true ) &&
-	     ( (*it1)->filename != NULL ) &&
-	     ( worker->getRequester() != NULL ) ) {
-	  char *reqstr;
-	  reqstr = (char*)_allocsafe( strlen( catalog.getLocale( 628 ) ) + strlen( (*it1)->filename ) + 1 );
-	  sprintf( reqstr, catalog.getLocale( 628 ), (*it1)->filename );
-	  worker->getRequester()->request( catalog.getLocale( 125 ), reqstr, catalog.getLocale( 11 ) );
-	  _freesafe( reqstr );
-	}
-	
-        worker_unlink( (*it1)->tempname );
-      }
-      delete *it1;
+    return extorder.m_use_virtual_temp_copies;
+}
+
+std::string WPUContext::getTempName4File( const char *filename )
+{
+  if ( filename == NULL ) return "";
+
+  calculateFilesizes();
+
+  TemporaryFileCache::TemporaryFileCacheEntry e = worker->getTempCopy( filename, m_progress_callback.getVal() );
+
+  if ( ! e.isValid() ) return "";
+
+  m_temp_files.push_back( e );
+
+  return e.getTempName();
+}
+
+void WPUContext::ref()
+{
+    m_reference_count++;
+}
+
+int WPUContext::unref()
+{
+    return --m_reference_count;
+}
+
+WPUProgressCallback::WPUProgressCallback( Worker *w ) : m_worker( w ), m_complete_sizes( 0 ), m_bytes_already_copied( 0 )
+{
+    m_last_update = time( NULL );
+}
+
+WPUProgressCallback::~WPUProgressCallback()
+{
+    if ( m_worker ) {
+        m_worker->removeStatebarText( m_text );
+    }
+}
+
+CopyfileProgressCallback::callback_return_t WPUProgressCallback::progress_callback( loff_t current_bytes,
+                                                                                    loff_t total_bytes )
+{
+    time_t now = time( NULL );
+
+    if ( m_worker ) {
+        if ( now != m_last_update ||
+             total_bytes == 0 ||
+             current_bytes == total_bytes ) {
+
+            m_worker->removeStatebarText( m_text );
+
+            if ( total_bytes != 0 && current_bytes < total_bytes ) {
+                if ( m_complete_sizes > 0 && m_complete_sizes > total_bytes ) {
+                    float v = current_bytes;
+                    v += m_bytes_already_copied;
+                    v *= 100.0;
+                    v /= m_complete_sizes;
+
+                    std::string s = AGUIXUtils::formatStringToString( catalog.getLocale( 969 ),
+                                                                      (float)current_bytes * 100.0 / total_bytes,
+                                                                      v );
+                    m_text = TimedText( s, now, now + 5 );
+                } else {
+                    std::string s = AGUIXUtils::formatStringToString( catalog.getLocale( 968 ),
+                                                                      (float)current_bytes * 100.0 / total_bytes );
+                    m_text = TimedText( s, now, now + 5 );
+                }
+
+                m_worker->pushStatebarText( m_text );
+
+                m_last_update = now;
+            }
+        }
+    }
+
+    if ( current_bytes == total_bytes ) {
+        m_bytes_already_copied += total_bytes;
+    }
+
+    return COPYFILE_CONTINUE;
+}
+
+void WPUProgressCallback::setCompleteFilesizes( loff_t sum )
+{
+    m_complete_sizes = sum;
+}
+
+void WPUContext::calculateFilesizes()
+{
+    if ( m_filesizes_calculated ) return;
+
+    loff_t sum = 0;
+
+    for ( int i = 0; i < 2; i++ ) {
+        if ( extlist[i] ) {
+            int id = extlist[i]->initEnum();
+            NM_extern_fe *efe = extlist[i]->getFirstElement( id );
+            while ( efe != NULL ) {
+                if ( efe->getFullname( false ) ) {
+                    NWC::FSEntry f( efe->getFullname( false ) );
+                    
+                    if ( f.isReg( true ) ) {
+                        loff_t filesize = 0;
+                        if ( f.isLink() == true ) {
+                            filesize = f.stat_dest_size();
+                        } else {
+                            filesize = f.stat_size();
+                        }
+
+                        sum += filesize;
+                    }
+                }
+
+                efe = extlist[i]->getNextElement( id );
+            }
+            extlist[i]->closeEnum( id );
+        }
+    }
+
+    m_filesizes_calculated = true;
+
+    if ( m_progress_callback.getVal() ) {
+        m_progress_callback->setCompleteFilesizes( sum );
     }
-  }
 }
